@@ -1,11 +1,10 @@
-#! /opt/local/bin/perl5.10.0
 use 5.010;
 use warnings;
 
     use Regexp::Grammars;
 
     my $balanced_brackets = qr{
-#        <debug:step>
+        <debug:step>
 
         <left_delim=(  \( )>
         (?:
